searchNodes=[{"doc":"Documentation for ISBN.","ref":"ISBN.html","title":"ISBN","type":"module"},{"doc":"Returns ISBN formatted. Examples iex&gt; ISBN.format(&quot;9992158107&quot;) &quot;99-9215-810-7&quot; iex&gt; ISBN.format(&quot;9992158106&quot;) nil","ref":"ISBN.html#format/1","title":"ISBN.format/1","type":"function"},{"doc":"Checks if the given string is a valid ISBN. Works with both ISBN-10 and ISBN-13. Allows hyphens and spaces in the string. Examples iex&gt; ISBN.valid?(&quot;9971502100&quot;) true iex&gt; ISBN.valid?(&quot;978-03-0640-615-7&quot;) true","ref":"ISBN.html#valid?/1","title":"ISBN.valid?/1","type":"function"},{"doc":"Provide function to validate ISBN field in a changeset","ref":"ISBN.Ecto.Changeset.html","title":"ISBN.Ecto.Changeset","type":"module"},{"doc":"Verifies if given field in the changeset has a valid ISBN. Examples iex&gt; {%{}, %{isbn: :string}} ...&gt; |&gt; Ecto.Changeset.cast(%{isbn: &quot;978-03-0640-615-7&quot;}, [:isbn]) ...&gt; |&gt; ISBN.Ecto.Changeset.validate_isbn(:isbn) #Ecto.Changeset&lt;action: nil, changes: %{isbn: &quot;978-03-0640-615-7&quot;}, errors: [], data: %{}, valid?: true&gt; iex&gt; {%{}, %{isbn: :string}} ...&gt; |&gt; Ecto.Changeset.cast(%{isbn: &quot;1234567890&quot;}, [:isbn]) ...&gt; |&gt; ISBN.Ecto.Changeset.validate_isbn(:isbn) #Ecto.Changeset&lt;action: nil, changes: %{isbn: &quot;1234567890&quot;}, errors: [isbn: {&quot;is invalid&quot;, []}], data: %{}, valid?: false&gt;","ref":"ISBN.Ecto.Changeset.html#validate_isbn/3","title":"ISBN.Ecto.Changeset.validate_isbn/3","type":"function"},{"doc":"ISBN A library to work with ISBN written in Elixir. The International Standard Book Number (ISBN) is a numeric commercial book identifier which is intended to be unique. Publishers purchase ISBNs from an affiliate of the International ISBN Agency. An ISBN is assigned to each separate edition and variation (except reprintings) of a publication. For example, an e-book, a paperback and a hardcover edition of the same book will each have a different ISBN. The ISBN is ten digits long if assigned before 2007, and thirteen digits long if assigned on or after 1 January 2007. The method of assigning an ISBN is nation-specific and varies between countries, often depending on how large the publishing industry is within a country. Reference here This library provides a validation that checks if the ISBN is valid and a formatter. The ISBN has check digit algorithm, you can check the details here.","ref":"readme.html","title":"ISBN","type":"extras"},{"doc":"If available in Hex, the package can be installed by adding isbnex to your list of dependencies in mix.exs: def deps do [ {:isbnex, &quot;~&gt; 0.2.0&quot;} ] end","ref":"readme.html#installation","title":"ISBN - Installation","type":"extras"},{"doc":"You can verify if a ISBN is valid by calling the function ISBN.valid?/1. Works with both ISBN-10 and ISBN-13. Allows hyphens and spaces in the string. iex&gt; ISBN.valid?(&quot;9971502100&quot;) true iex&gt; ISBN.valid?(&quot;99-9215-810-7&quot;) true iex&gt; ISBN.valid?(&quot;978-0-306-40615-7&quot;) true iex&gt; ISBN.valid?(&quot;978 0 306 40615 7&quot;) true iex&gt; ISBN.valid?(&quot;0-9752298-0-X&quot;) true iex&gt; ISBN.valid?(&quot;978-0-306-40615-6&quot;) false The ISBN.format/1 returns ISBN wrapped. iex&gt; ISBN.format(&quot;9780306406157&quot;) &quot;978-03-0640-615-7&quot; iex&gt; ISBN.format(&quot;9992158107&quot;) &quot;99-9215-810-7&quot; iex&gt; ISBN.format(&quot;111111&quot;) nil","ref":"readme.html#quick-start","title":"ISBN - Quick Start","type":"extras"},{"doc":"You can use ISBN.Ecto.Changeset.validate_isbn/3 function to validate a field in your changeset. Example: defmodule MyApp.Libraries.Book do @moduledoc &quot;&quot;&quot; The Book schema. &quot;&quot;&quot; use Ecto.Schema import Ecto.Changeset # Import this module import ISBN.Ecto.Changeset schema &quot;books&quot; do field :isbn, :string, null: false end @doc false def changeset(book, attrs) do book |&gt; cast(attrs, [:isbn]) |&gt; validate_isbn([:isbn]) end end iex&gt; changeset = MyApp.Libraries.Book.changeset(%MyApp.Libraries.Book{}, %{isbn: &quot;12345567&quot;}) iex&gt; {:error, %Ecto.Changeset{}} = Repo.insert(changeset) iex&gt; changeset #Ecto.Changeset&lt;action: :insert, changes: %{isbn: &quot;1234567890&quot;}, errors: [isbn: {&quot;is invalid&quot;, []}], data: #MyApp.Libraries.Book&lt;&gt;, valid?: false&gt;","ref":"readme.html#validation-with-changeset","title":"ISBN - Validation with Changeset","type":"extras"},{"doc":"The docs can be found at https://hexdocs.pm/isbnex.","ref":"readme.html#docs","title":"ISBN - Docs","type":"extras"},{"doc":"Feel free to contribute to this project. If you have any suggestions or bug reports just open an issue or a PR.","ref":"readme.html#contribute","title":"ISBN - Contribute","type":"extras"}]